pm4py.algo.evaluation.precision.variants package
================================================

Submodules
----------

pm4py.algo.evaluation.precision.variants.align\_etconformance module
--------------------------------------------------------------------

.. automodule:: pm4py.algo.evaluation.precision.variants.align_etconformance
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.algo.evaluation.precision.variants.etconformance\_token module
--------------------------------------------------------------------

.. automodule:: pm4py.algo.evaluation.precision.variants.etconformance_token
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.evaluation.precision.variants
   :members:
   :undoc-members:
   :show-inheritance:
